$TITLE GATT/WTO GLOBAL ECONOMY-WIDE MODEL

******************************************
*    THIS PROGRAM WILL
*    GENERATE THE BENCHMARK DATA FILE:
*      
*    REQUIRED DATA ARE WRITTEN IN 
*    SPARSE FORM AS A GAMS INCLUDE FILE
*
*    NOTE: In the data file, you need
*    to change set definitions FD and NF so
*    there are subsets of G,  FD(G) and NF(G)
******************************************

FILE BMK /DATA.GMS/;
PUT BMK;

$INCLUDE SAM.INC
$INCLUDE PAR.INC
$INCLUDE TAX.INC



ALIAS (PF,F);

PARAMETER

  A0(G,R)               BENCHMARK ARMINGTON COMPOSITE
  C0(G,R)               BENCHMARK HOUSEHOLD DEMAND
  D0(G,R)               BENCHMARK DOMESTIC USE OF DOMESTIC PRODUCT
  E0(F,R)		ENDOWMENT
  F0(F,G,R)             BENCHMARK FACTOR USE
  G0(G,R)               GOVERNMENT DEMAND
  I0(G,GG,R)            USE MATRIX (GOODS INPUT G TO GG)
  MKT_ACC(FD,R)		CURRENT MARKET ACCESS
  M0(G,R,TR)		BENCHMARK IMPORTS AT CONSUMER PRICES
  QEXPAND(FD,R)         DOMESTIC QUOTA EXPANSION RATE
  S0(G,R)               COMPOSITE INVESTMENT DEMAND
  SXTOTAL(G,R)		TOTAL EXPORT SUBSIDIES
  TAXBILL0(G,R)         TOTAL NOMINAL TAX OR TRANSFER BILL
  TRANSF0(*)		CAPITAL ACCOUNT TRANSFER
  TY0			PRODUCTION SUBSIDIES
  VAT(R)                TOTAL GDP IN VALUE ADDED TERMS
  X0(G,R,TR)            BENCHMARK EXPORTS AT PRODUCER COST
  Y0(G,R)               BENCHMARK OUTPUT

  QR0(G,R,TR)           FOREIGN HELD QUOTA RENTS 
  QD0(G,R,TR)           DOMESTIC HELD QUOTA RENTS FOR AGRICULTURE
  QR0TOT		TOTAL FOREIGN HELD QUOTA RENTS


  ELASA(G,R)            TOP LEVEL ELAS OF SUB IN ARMINGTON FUNCTION
  ELASAIM(G,R)          BOTTOM LEVEL ELAS OF SUB IN ARMINGTON FUNCTION
  ELASC(R)              TOP LEVEL ELAS OF SUB IN CONSUMPTION
  ELASCFD(R)            ELAS OF SUB AMONG FOOD ITEMS IN CONSUMPTION
  ELASCNF(R)            ELAS OF SUB AMONG NON-FOOD ITEMS IN CONSUMPTION
  ELASP(G,R)            TOP LEVEL ELAS OF SUB IN PRODUCTION
  ELASPIN(G,R)          INTM NEST ELAS OF SUB IN PRODUCTION
  ELASPVA(G,R)          VA NEST ELAS OF SUB IN PRODUCTION

  AD(G,R,TR)		ANTIDUMPING DUTIES
  CHK			MACRO ACCOUNTING CHECK VARIABLE
  HOLDNF(NF,R,TR)       NF TARIFF HOLD VARIABLE
  HOLDF(FD,R,TR)        FD TARIFF HOLD VARIABLE
  HOLDTM(G,R,TR)	TM HOLD VARIABLE
  HOLDSX(G,R,TR)	EXPORT SUBSIDY HOLD VARIABLE
  PUNDER(G,R,TR)	ANTIDUMPING PRICE UNDERTAKINGS
  QRATE(G,R,TR)         FOREIGN QUOTA RATES
  QDRATE(FD,R,TR)       DOMESTIC QUOTA RATES
  SX(G,R,TR)            EXPORT SUBSIDY RATE
  SXRATIO(G,R)		EXPORT SUBSIDY CUT RATIO
  TAXBILL0		NET SECTORAL TAX BILL
  TM(G,R,TR)            IMPORT TAX RATE
  TY			PRODUCTION SUBSIDY RATE
  VA0(G,R)              DOMESTIC VALUE ADDED
  VASHARE(G,R)          VALUE ADDED SHARES   ;
  
******************************************
*EXTRACT ELASTICITIES FROM PARAMETER FILES
******************************************
ELASP(G,R)     	=     PELAS(G,'TELASP');
ELASPVA(G,R)   	=     PELAS(G,'TELASPVA');
ELASPIN(G,R)   	=     PELAS(G,'TELASPIN');
ELASA(G,R)     	=     PELAS(G,'TELASA');  
ELASAIM(G,R)   	=     PELAS(G,'TELASAIM');  
ELASC(R)       	=     CELAS(R,'TELASC');       
ELASCFD(R)     	=     CELAS(R,'TELASCFD');  
ELASCNF(R)     	=     CELAS(R,'TELASCNF');  

*******************************************
*EXTRACT POLICY VARIABLES FROM POLICY FILES
*******************************************

*********************************
*    EXTRACT DUMPING DUTIES
*********************************
AD(G,R,TR) = DUMPING(G,TR,R);
PUNDER(G,R,TR) = PUNDRTK(G,TR,R);

*********************************
*    LOAD APPLIED RATES FROM GTAP
*********************************
TM(G,R,TR)      = TARIFFS(G,TR,R);

*********************************
*    LOAD EU RATES AGAINST EFTA
*********************************
TM(NF,'EFTA__','EUNION') = 0.00;

*********************************
*    LOAD EFTA RATES AGAINST EU
*********************************
TM(NF,'EUNION','EFTA__') = 0.00;

*********************************
*    LOAD RATES AGAINST 
*    EU V EU
*    EFTA V EFTA
*
*    NOTE THAT RATE AGAINST EFTA IS
*    THE GTAP AVERAGE SO THAT 
*    EFTA RATE IS USED 
*    AS GTAP AVERAGE AGAINST ROW
*********************************
TM(NF,'EFTA__','EFTA__') = 0.00;
TM(G,'EUNION','EUNION') = 0.00;

*********************************
*    LOAD HOLD VARIABLES FOR 
*    BENCHMARK TARIFFS AND
*    SUBSIDY RATES
*********************************
EX_TAXES(FD,TR,'EFTA__') = -EFTA_SX(FD,'EFTA__')/(SUM(R,SAM('EFTA__',FD,R))+EFTA_SX(FD,'EFTA__'));

**********************************
*   ADJUST GTAP MFA RATES TO AN
*   APPARENT fob BASIS
**********************************

QRS('TEXTLS',TR,R)   = QRS('TEXTLS',TR,R)/(1+QRS('TEXTLS',TR,R));
QRS('APPARL',TR,R)   = QRS('APPARL',TR,R)/(1+QRS('APPARL',TR,R));

**********************************
*   CALIBRATE MFA AS A SHARE
*   OF fob PRICES WITH
*   CORRECTION TO GTAP RATES           
**********************************

QRATE('TEXTLS',R,TR)   = QRS('TEXTLS',TR,R)/(1+QRS('TEXTLS',TR,R));
QRATE('APPARL',R,TR)   = QRS('APPARL',TR,R)/(1+QRS('APPARL',TR,R));

HOLDNF(NF,R,TR) = TM(NF,R,TR);
HOLDF(FD,R,TR)  = TM(FD,R,TR);
HOLDSX(G,R,TR)	= -EX_TAXES(G,TR,R);
HOLDTM(G,R,TR)  = TM(G,R,TR);

*********************************
*    LOAD SUBSIDY RATES
*********************************
SX(G,R,TR)      = (HOLDSX(G,R,TR) - PUNDER(G,R,TR))/
                      (1 - HOLDSX(G,R,TR) + PUNDER(G,R,TR));
DISPLAY SX;

*********************************
*   ADJUST TARIFFS FOR 
*   DUMPING DUTIES
*********************************
TM(G,R,TR) = TM(G,R,TR) + AD(G,R,TR);

*******************************************************
*BENCHMARK VALUES FOR ACTIVITY VARIABLES
*******************************************************
I0(G,GG,R)    	= SAM(R,G,GG);
F0(F,G,R)     	= SAM(R,F,G);
C0(G,R) 	= SAM(R,G,'COMPHH');
G0(G,R)      	=  0;
TAXBILL0(G,R)  	= SAM(R,'COMPHH',G);
S0(G,R)       	=   SAM(R,G,'INVEST');

*	EXPORTS AT DOMESTIC PRICES:
X0(G,R,TR)    	=   SAM(R,G,TR) /(1 - SX(G,R,TR));
X0(G,R,TR)$(X0(G,R,TR) LT 0.1 ) = 0 ; 


********************************************************************************
*CLEAN-UP SUPPORT IN RESIDUAL ROW                                              *
*                                                                              *

PARAMETER FIX(G,R);
FIX(G,'ROW___') = SUM(TR, 
                  X0(G,TR,'ROW___') * (1-SX(G,TR,'ROW___')) * TM(G,TR,'ROW___') );
C0(G,'ROW___') 	=  C0(G,'ROW___') + FIX(G,'ROW___');
TAXBILL0(G,'ROW___')	= TAXBILL0(G, 'ROW___') + FIX(G,'ROW___');
DISPLAY C0;

*                                                                              *
*                                                                              *
********************************************************************************


DISPLAY X0;
QR0(G,R,TR)    	=   QRATE(G,R,TR) * X0(G,R,TR) ;
X0(G,R,TR)    	=   X0(G,R,TR) - QR0(G,R,TR);
D0(G,R) 	=   SUM(GG, I0(G,GG,R)) + G0(G,R) + C0(G,R) + S0(G,R) 
			- SUM(TR,QR0(G,TR,R))
   			- SUM(TR, X0(G,TR,R)  * (1-SX(G,TR,R)) 
			* (1 + TM(G,TR,R)));

TY0(G,R) = TAXBILL0(G,R)
		- SUM(TR, X0(G,TR,R) * (1-SX(G,TR,R)) * TM(G,TR,R))
		+ SUM(TR, X0(G,R,TR) * SX(G,R,TR));

* CALCULATE TOTAL DOMESTIC PRODUCTION ON A VALUE ADDED OR COST BASIS

Y0(G,R)       = SUM(F, F0(F,G,R)) + SUM(GG, I0(GG,G,R)) + TY0(G,R);

CHK(G,R) = 100 * (SUM(TR, X0(G,R,TR)) + D0(G,R) 
                 + SUM(TR, QR0(G,R,TR)) - Y0(G,R))/Y0(G,R);
DISPLAY CHK;

D0(G,R) = Y0(G,R) - SUM(TR, X0(G,R,TR)) ;

C0(G,R) = D0(G,R) + SUM(TR, X0(G,TR,R) * (1-SX(G,TR,R)) * (1 + TM(G,TR,R)))
	 - (SUM(GG, I0(G,GG,R)) + G0(G,R) + S0(G,R))  + SUM(TR,QR0(G,TR,R));

E0(F,R)      =   SUM(G,F0(F,G,R));

A0(G,R)       = D0(G,R) + 
		SUM(TR, X0(G,TR,R) * (1-SX(G,TR,R)) * (1 + TM(G,TR,R)))
                + SUM(TR,QR0(G,TR,R));

TRANSF0(R) = SUM(G, C0(G,R)+S0(G,R)+G0(G,R)) 
		- SUM(F, E0(F,R)) - SUM(G,TAXBILL0(G,R)) - SUM(G,SUM(TR,QR0(G,R,TR))) ;
TRANSF0("CHK") = SUM(R, TRANSF0(R));
QR0TOT    =  SUM(TR,SUM(R, (SUM(G,QR0(G,R,TR)))));
DISPLAY QR0TOT;
DISPLAY TRANSF0;

****************************************************
*   LOAD BASE LEVEL PRODUCTION SUPPORT
*   AND REBALANCE SOCIAL ACCOUNTING ALLOCATION
*   OF VALUE ADDED IN THE PROCESS  
*
*   CALCULATE PRODUCTION AND EXPORT SUBSIDY RATES
****************************************************
DISPLAY TY0;
TY(G,R) = TY0(G,R) / Y0(G,R);
DISPLAY TY;

*STRIP OUT RESIDUAL EFTA SUPPORT
F0('CAPTAL',G,'EFTA__')  	=  F0('CAPTAL',G,'EFTA__') + (TY0(G,'EFTA__'));
TY0(G,'EFTA__') 		= 0.00;

*RE-LOAD ACTUAL EFTA SUPPORT
TY0(FD,'EFTA__') = -Y0(FD,'EFTA__')*(PROD_SUB(FD,'EFTA__'));
DISPLAY TY0;
F0('CAPTAL',FD,'EFTA__')	=  F0('CAPTAL',FD,'EFTA__') - (TY0(FD,'EFTA__'));

*STRIP OUT RESIDUAL ROW SUPPORT
F0('CAPTAL',G,'ROW___')  	=  F0('CAPTAL',G,'ROW___') + .25*(TY0(G,'ROW___'));
F0('LABOUR',G,'ROW___')  	=  F0('LABOUR',G,'ROW___') + .75*(TY0(G,'ROW___'));
TY0(G,'ROW___') 		= 0.00;


* ADJUST ENDOWMENT INDEXES
E0(F,R)   	=   SUM(G,F0(F,G,R));

* CONVERT TY0 TO A RATE:
TY(G,R) 		= TY0(G,R) / Y0(G,R);
DISPLAY TY;

* CALCULATE TOTAL EXPORT SUPPORT
SXTOTAL(G,R) 		=  SUM(TR, X0(G,R,TR) * SX(G,R,TR));

*CALCULATE CURRENT MARKET ACCESS AS A SHARE, AND SET SUBSIDY RATES
*FOR AGRICULTURE

MKT_ACC(FD,R) = 1 - (D0(FD,R)/A0(FD,R));
QEXPAND(FD,R) = MAX(1,(.05/MKT_ACC(FD,R)));
QEXPAND('GRAINS','JAPAN_') = MAX(1,(.08/MKT_ACC('GRAINS','JAPAN_')));
QD0(FD,R,TR) = X0(FD,R,TR) * (1-SX(FD,R,TR)) * (TM(FD,R,TR));
QD0(G,R,TR)$(QD0(G,R,TR) LT 0.1 ) = 0 ; 
QDRATE(FD,TR,R) = TM(FD,TR,R); 
*. TM(FD,TR,R) = 0;
DISPLAY F0, QD0, QDRATE, MKT_ACC, QEXPAND;



* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
* !!!!!!	FILTER SOME OF THESE PARAMETERS:     !!!!!!!!
* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

$BATINCLUDE wrtset.gms BMK G
$BATINCLUDE wrtset.gms BMK R
$BATINCLUDE wrtset.gms BMK F
$BATINCLUDE wrtset.gms BMK FD
$BATINCLUDE wrtset.gms BMK NF

PUT 'ALIAS (G,GG);'/;

*	SCALE SO THAT NUMBERS ARE CLOSE TO UNITY:

Y0( G, R)		= Y0( G, R)				/ 10000;
TY0( G, R)		= TY0( G,R)				/ 10000;
SXTOTAL( G, R)		= SXTOTAL( G, R)			/ 10000;
X0( G, R, TR )		= X0( G, R, TR )			/ 10000;
F0( F, G, R )		= F0( F, G, R )				/ 10000;
I0( G, GG, R )		= I0( G, GG, R )			/ 10000;
A0( G, R )		= A0( G, R )				/ 10000;
D0( G, R )		= D0( G, R )				/ 10000;
C0( G, R )		= C0( G, R )				/ 10000;
G0( G, R )		= G0( G, R )				/ 10000;
S0( G, R )		= S0( G, R )				/ 10000;
E0( F, R )		= E0( F, R )				/ 10000;
TRANSF0( R )		= TRANSF0( R )				/ 10000;
QR0(G,R,TR)             = QR0(G,R,TR)                           / 10000;
QD0(G,R,TR)             = QD0(G,R,TR)                           / 10000;

$BATINCLUDE wrtprm.gms BMK Y0 G R 
$BATINCLUDE wrtprm.gms BMK X0 G R TR 
$BATINCLUDE wrtprm.gms BMK QD0 G R TR
$BATINCLUDE wrtprm.gms BMK QR0 G R TR
$BATINCLUDE wrtprm.gms BMK F0 F G R 
$BATINCLUDE wrtprm.gms BMK I0 G GG R 
$BATINCLUDE wrtprm.gms BMK A0 G R 
$BATINCLUDE wrtprm.gms BMK D0 G R 
$BATINCLUDE wrtprm.gms BMK C0 G R 
$BATINCLUDE wrtprm.gms BMK G0 G R 
$BATINCLUDE wrtprm.gms BMK S0 G R 
$BATINCLUDE wrtprm.gms BMK E0 F R 

$BATINCLUDE wrtprm.gms BMK ELASP G R 
$BATINCLUDE wrtprm.gms BMK ELASPVA G R 
$BATINCLUDE wrtprm.gms BMK ELASPIN G R 
$BATINCLUDE wrtprm.gms BMK ELASC R 
$BATINCLUDE wrtprm.gms BMK ELASCFD R 
$BATINCLUDE wrtprm.gms BMK ELASCNF R 
$BATINCLUDE wrtprm.gms BMK ELASAIM G R 
$BATINCLUDE wrtprm.gms BMK ELASA G R 

$BATINCLUDE wrtprm.gms BMK TM G R TR 
$BATINCLUDE wrtprm.gms BMK SX G R TR 
$BATINCLUDE wrtprm.gms BMK SXTOTAL G R
$BATINCLUDE wrtprm.gms BMK TY G R
$BATINCLUDE wrtprm.gms BMK TY0 G R
$BATINCLUDE wrtprm.gms BMK HOLDNF NF R TR
$BATINCLUDE wrtprm.gms BMK HOLDF  FD R TR
$BATINCLUDE wrtprm.gms BMK HOLDTM G R TR
$BATINCLUDE wrtprm.gms BMK AD G R TR
$BATINCLUDE wrtprm.gms BMK PUNDER G R TR
$BATINCLUDE wrtprm.gms BMK HOLDSX G R TR
$BATINCLUDE wrtprm.gms BMK QRATE G R TR
$BATINCLUDE wrtprm.gms BMK MKT_ACC FD R
$BATINCLUDE wrtprm.gms BMK QEXPAND FD R

$BATINCLUDE wrtprm.gms BMK URCUTS G R
$BATINCLUDE wrtprm.gms BMK TRANSF0 R 

