*EXP2.GMS  MFA libearlization

*    READ THE BENCHMARK DATA SET:

$ONEMPTY

$INCLUDE DATA.GMS

C0(G,R) = C0(G,R) + S0(G,R);

ALIAS (G,GG), (R,TR);

*    Define the set of regions for the
*    purpose of indexing import quotas

SET REGNUM(R) / AUSTNZ R1, 
                JAPAN_ R2, 
                CANADA R3, 
                U_S_A_ R4, 
                EUNION R5,
                EFTA__ R6, 
                AFRICA R7, 
                CHINA_ R8,
                EASIA_ R9, 
                SOASIA R10, 
                LAT_AM R11,
                EEUROP R12, 
                ROW___ R13 / ;

SET SCENARIO /TARIFFS,
              QUOTAS / ;


PARAMETER PM0(G,R,TR)    BENCHMARK INTERNAL PRICE OF IMPORTS;

PARAMETER       SWITCH                  CAPITAL ACCUMULATION SWITCH
                QENDOW(G,R)             QUOTA SCALING VARIABLE
                windex0(r)              BENCHMARK WELFARE INDEX
                windex1(R,SCENARIO)     INDEX OF WELFARE (EV) RELATIVE TO BENCHMARK
                EV(R,SCENARIO)       EQUIVALENT VARIATION IN 1990 DOLLARS
                BASIS(R)                BENCHMARK GDP IN 1990 DOLLARS
                ;

* NOTE: switch=0 turns off dynamics

SWITCH      = 0;
QENDOW(G,R) = 1;
TM(FD,R,TR) = 0;
PM0(G,R,TR) = (1 - SX(G,R,TR)) * (1 + TM(G,R,TR));
$OFFEMPTY

$INCLUDE TheModel.gms


***********************************************
*  INITIAL CALIBRATION
***********************************************

IBRD.WORKSPACE = 24;
$INCLUDE IBRD.GEN
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
IBRD.ITERLIM = 10;
IBRD.RESLIM = 100000;
IBRD.OPTFILE=4;
SOLVE IBRD USING MCP;

*********************************
*  SET-UP FOR SOME REPORTING OF
*  RESULTS IN TABLES, CALIBRATE
*  SCALE EFFECT VARIABLES
*  WITH REFERENCE TO BENCHMARK
*********************************

BASIS(R) = RA.L(R);
WINDEX0(R) = C.L(R);


******** The experiment ********

IBRD.ITERLIM = 200000;

****************************
* MFA liberalization 
****************************


SET MFA(G)  /  TEXTLS,
               APPARL /;

******************************************************************
*PHASE-DOWN OF MFA AND RELATED TARIFFS BY GATT MEMBERS
******************************************************************
DISPLAY 'OLD PROTECTION -- INCLUDING TARIFF EQUIVALENTS FOR AGRCULTURE', TM;

*Here we eliminate textile and clothing tariffs
TM(MFA,R,TR)   = AD(MFA,R,TR);

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

windex1(R,"tariffs")=C.L(R);

*Here we increase quotas until they are non-binding
QENDOW(MFA,R) = 4;

display 'NEW PROTECTION -- TEXTILE AND CLOTHING CUTS', TM, SX;

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

windex1(R,"quotas")=C.L(R);


****************************************************************
* REPORT NON-WELFARE RESULTS 
****************************************************************

SET WTAB /REAL_W, W_GRAINS, W_PRFOOD, W_R/;
SET GTAB / WAGES, CONGOOD, OTHRMF /;
SET GLOBE / TOTAL /;

PARAMETER      OUTPUT(G,R)         CHANGE IN OUTPUT
          EXPORTS(G,R)        CHANGE IN EXPORTS
          IMPORTS(G,R)        CHANGE IN IMPORTS
          WAGES(R,WTAB)       CHANGE IN REAL WAGES
          WEXPORT(G)          CHANGE IN WORLD TRADE BY SECTOR
          WTRADE(GLOBE)       CHANGE IN WORLD TRADE
          REALGDP(R)          REAL CHANGES IN GDP
          GRAINP(R,GTAB)          CHANGE IN RELATIVE GRAIN PRICES
          STRADE(G,GLOBE)          SECTORAL TRADE
          TTRADE(R,GLOBE)          TOTAL TRADE;

GRAINP(R,'WAGES')  = PA.L('GRAINS',R)/PF.L('LABOUR',R);
GRAINP(R,'CONGOOD')  = PA.L('GRAINS',R)/PC.L(R);
GRAINP(R,'OTHRMF')  = PA.L('GRAINS',R)/PA.L('OTHRMF',R);

OUTPUT(G,R)    =    Y.L(G,R) - 1;
EXPORTS(G,R)   =    (((Y.L(G,R)*Y0(G,R)) - (DOM.L(G,R)*D0(G,R)))/
                            (Y0(G,R)-D0(G,R)))-1;
IMPORTS(G,R)   =    (((A.L(G,R)/PA.L(G,R)) - (DOM.L(G,R)*(D0(G,R)/A0(G,R))))
               * (A0(G,R) / (A0(G,R)-D0(G,R)))) -1 ;
WEXPORT(G)     =    SUM(R,(((Y.L(G,R)*Y0(G,R)) - (DOM.L(G,R)*D0(G,R))))/
                     SUM(TR,(Y0(G,TR)-D0(G,TR))))-1;
WTRADE(GLOBE)  =    SUM(R,SUM(G,(((Y.L(G,R)*Y0(G,R)) -
                    (DOM.L(G,R)*D0(G,R)))))/
                     SUM(TR,SUM(G,(Y0(G,TR)-D0(G,TR)))))-1;
STRADE(G,GLOBE)          =    WEXPORT(G);
TTRADE(R,GLOBE)          =    WTRADE(GLOBE);
WAGES(R,'REAL_W')   =    PF.L('LABOUR',R)/PC.L(R);
WAGES(R,'W_GRAINS') =    PF.L('LABOUR',R)/PA.L('GRAINS',R);
WAGES(R,'W_PRFOOD') =    PF.L('LABOUR',R)/PA.L('PRFOOD',R);
WAGES(R,'W_R')      =    PF.L('LABOUR',R)/PF.L('CAPTAL',R);
REALGDP(R)          =    (SUM(G,(Y.L(G,R)*Y0(G,R))) /
                                SUM(G,Y0(G,R)))-1;
DISPLAY OUTPUT, IMPORTS, EXPORTS, WAGES, REALGDP, WEXPORT, WTRADE;

****************************************************************
* REPORT WELFARE RESULTS 
****************************************************************

PARAMETER PERCENT(R,SCENARIO);

PERCENT(R,"TARIFFS") =  WINDEX1(R,"TARIFFS")-WINDEX0(R);
PERCENT(R,"QUOTAS")   =  WINDEX1(R,"QUOTAS")-WINDEX1(R,"TARIFFS");
BASIS(R)              =  BASIS(R) * 10000;
EV(R,SCENARIO)       =  BASIS(R)*PERCENT(R,SCENARIO);

DISPLAY 'WELFARE ESTIMATES', BASIS, WINDEX0, WINDEX1, EV, PERCENT;

FILE PRN /EXP2.PRN/;
$BATINCLUDE wrtprn.gms PRN "PERCENT EV FOR STATIC MODEL" PERCENT R SCENARIO 
$BATINCLUDE wrtprn.gms PRN "1992 DOLLAR EV" EV R SCENARIO 
$BATINCLUDE wrtprn.gms PRN "REAL OUTPUT" OUTPUT G R
$BATINCLUDE wrtprn.gms PRN "EXPORTS" EXPORTS G R
$BATINCLUDE wrtprn.gms PRN "WAGES" WAGES R WTAB
$BATINCLUDE wrtprn.gms PRN "RELATIVE GRAIN PRICES" GRAINP R GTAB
$BATINCLUDE wrtprn.gms PRN "SECTORAL TRADE EFFECTS" STRADE G GLOBE
$BATINCLUDE wrtprn.gms PRN "GLOBAL TRADE EFFECTS" TTRADE R GLOBE
