*EXP3.GMS  The Uruguay Round

*    READ THE BENCHMARK DATA SET:

$ONEMPTY

$INCLUDE DATA.GMS

C0(G,R) = C0(G,R) + S0(G,R);

ALIAS (G,GG), (R,TR);

*    Define the set of GATT members

SET GATT(R) / AUSTNZ,
              CANADA,
              U_S_A_,
              EUNION,
              JAPAN_,
              EFTA__,
              EEUROP,
              SOASIA,
              EASIA_,
              AFRICA,
              LAT_AM,
              ROW___
            / ;

*    Define the set of regions for the
*    purpose of indexing import quotas

SET REGNUM(R) / AUSTNZ R1, 
                JAPAN_ R2, 
                CANADA R3, 
                U_S_A_ R4, 
                EUNION R5,
                EFTA__ R6, 
                AFRICA R7, 
                CHINA_ R8,
                EASIA_ R9, 
                SOASIA R10, 
                LAT_AM R11,
                EEUROP R12, 
                ROW___ R13 / ;

*    Define the set of Uruguay Round scenarios

SET SCENARIO /              
               TEXT_APP,
               O_IND,
               PRIMARY,
               AGR,
               DYNAMICS,
               TOTAL
            / ;


PARAMETER PM0(G,R,TR)    BENCHMARK INTERNAL PRICE OF IMPORTS;

PARAMETER       SWITCH                  CAPITAL ACCUMULATION SWITCH
                QENDOW(G,R)             QUOTA SCALING VARIABLE
                windex0(r)              BENCHMARK WELFARE INDEX
                windex1(R,SCENARIO)     INDEX OF WELFARE (EV) RELATIVE TO BENCHMARK
                EV(R,SCENARIO)          EQUIVALENT VARIATION IN 1990 DOLLARS
                BASIS(R)                BENCHMARK GDP IN 1990 DOLLARS
                ;

* NOTE: switch=0 turns off dynamics

SWITCH      = 1;
QENDOW(G,R) = 1;
TM(FD,R,TR) = 0;
PM0(G,R,TR) = (1 - SX(G,R,TR)) * (1 + TM(G,R,TR));
$OFFEMPTY

$INCLUDE TheModel.gms


***********************************************
*  INITIAL CALIBRATION
***********************************************

IBRD.WORKSPACE = 24;
$INCLUDE IBRD.GEN
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
IBRD.ITERLIM = 10;
IBRD.RESLIM = 100000;
IBRD.OPTFILE=4;
SOLVE IBRD USING MCP;

*********************************
*  SET-UP FOR SOME REPORTING OF
*  RESULTS IN TABLES, CALIBRATE
*  SCALE EFFECT VARIABLES
*  WITH REFERENCE TO BENCHMARK
*********************************

BASIS(R) = RA.L(R);
WINDEX0(R) = C.L(R);


******** UR COMMITMENTS ********

IBRD.ITERLIM = 200000;

****************************
* URUGUAY ROUND SIMULATIONS
****************************

SET OECD(R) / AUSTNZ,
              CANADA,
              U_S_A_,
              EUNION,
              JAPAN_,
              EFTA__
            / ;

SET NOECD(R) / SOASIA,
              EASIA_,
              AFRICA,
              LAT_AM,
              ROW___
            / ;

SET MFA(G)  /  TEXTLS,
               APPARL /;

SET O_IND(G) / LUMBPP, PETROL, CHEMCL,
               STEELM, OMETAL, FABMTL,
               TSPEQP, OMACHN, OTHRMF / ;

SET PRIMARY(G) / FOREST, FISHRY, MINING /;
                
SET SCUT(G) / GRAINS,
              OCROPS,
              LVSTCK,
              PRFOOD /;


SET MG(G)    MERCHANDISE SECTORS      / GRAINS, OCROPS, LVSTCK,
                                        FOREST, FISHRY, MINING,
                                        PRFOOD, TEXTLS, APPARL,
                                        LUMBPP, PETROL, CHEMCL,
                                        STEELM, OMETAL, FABMTL,
                                        TSPEQP, OMACHN, OTHRMF
                                      /;


PARAMETER      FACTOR1(R)     EXPORT SUBSIDY CUT RATE
               FACTOR2(R)     PRODUCTION SUBSIDY CUT RATE;

     FACTOR1('AUSTNZ') = 0.72;
     FACTOR1('CANADA') = 0.36;
     FACTOR1('U_S_A_') = 0.36;
     FACTOR1('JAPAN_') = 0.00;
     FACTOR1('EUNION') = 0.36;
     FACTOR1('EFTA__') = 0.36;
     FACTOR1('ROW___') = 0.24;
     FACTOR2('AUSTNZ') = 0.00;
     FACTOR2('CANADA') = 0.00;
     FACTOR2('U_S_A_') = 0.00;
     FACTOR2('JAPAN_') = 0.00;
     FACTOR2('EUNION') = 0.00;
     FACTOR2('EFTA__') = 0.00;
     FACTOR2('ROW___') = 0.00;


*!!!!!!!!TEXTILES AND CLOTHING!!!!!!!!
******************************************************************
*PHASE-DOWN OF MFA AND RELATED TARIFFS BY GATT MEMBERS
******************************************************************
DISPLAY 'OLD PROTECTION -- INCLUDING TARIFF EQUIVALENTS FOR AGRCULTURE', TM;

TM(MFA,R,TR)   = (HOLDTM(MFA,R,TR)*(1+URCUTS(MFA,TR))) + AD(MFA,R,TR);
QENDOW(MFA,R) = 4;
TM(MFA,'EFTA__','EUNION')=0.00 + AD(MFA,'EFTA__','EUNION');
TM(MFA,'EUNION','EFTA__')=0.00 + AD(MFA,'EUNION','EFTA__');

display 'NEW PROTECTION -- TEXTILE AND CLOTHING CUTS', TM, SX;

****************************************************************
* SOLVE THE COUNTERFACTUAL 
****************************************************************

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

****************************************************************
* REPORT RESULTS 
****************************************************************

 windex1(r,'TEXT_APP')=C.L(R);

*!!!!!!!!OTHER INDUSTRY!!!!!!!!

****************************************************************
* OTHER INDUSTRY
****************************************************************

TM(O_IND,R,TR)= (HOLDTM(O_IND,R,TR)*(1+URCUTS(O_IND,TR))) + AD(O_IND,R,TR);
QENDOW(O_IND,R) = 4;
TM(O_IND,'EFTA__','EUNION')=0.00 + AD(O_IND,'EFTA__','EUNION');
TM(O_IND,'EUNION','EFTA__')=0.00 + AD(O_IND,'EUNION','EFTA__');

****************************************************************
* SOLVE THE COUNTERFACTUAL 
****************************************************************

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

****************************************************************
* REPORT RESULTS 
****************************************************************

 windex1(r,'O_IND')=C.L(R);

*!!!!!!!!PRIMARY!!!!!!!!

****************************************************************
* PRIMARY SECTORS
****************************************************************

TM(PRIMARY,R,TR)= (HOLDTM(PRIMARY,R,TR)*(1+URCUTS(PRIMARY,TR))) + AD(PRIMARY,R,TR);
TM(PRIMARY,'EFTA__','EUNION')=0.00 + AD(PRIMARY,'EFTA__','EUNION');
TM(PRIMARY,'EUNION','EFTA__')=0.00 + AD(PRIMARY,'EUNION','EFTA__');

****************************************************************
* SOLVE THE COUNTERFACTUAL 
****************************************************************

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

****************************************************************
* REPORT RESULTS 
****************************************************************

 windex1(r,'PRIMARY')=C.L(R);


*!!!!!!!!AGRICULTURE!!!!!!!!

******************************************************************
*PHASE-DOWN OF AGRICULTURE PROTECTION BY GATT MEMBERS
*  note that we solve the URAA loosely, in stages, before
*  solving for the full URAA at the end.  This is because
*  some of the quota "markets" shut down.
******************************************************************
PARAMETER TEMP(FD,R);
TEMP(FD,R) = QENDOW(FD,R);

QENDOW(FD,GATT) = TEMP(FD,GATT)*(1+(.2*(QEXPAND(FD,GATT)-1)));
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=2;
  SOLVE IBRD USING MCP;
QENDOW(FD,GATT) = TEMP(FD,GATT)*(1+(.4*(QEXPAND(FD,GATT)-1)));
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=2;
  SOLVE IBRD USING MCP;
QENDOW(FD,GATT) = TEMP(FD,GATT)*(1+(.6*(QEXPAND(FD,GATT)-1)));
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=2;
  SOLVE IBRD USING MCP;
QENDOW(FD,GATT) = TEMP(FD,GATT)*(1+(.8*(QEXPAND(FD,GATT)-1)));
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=2;
  SOLVE IBRD USING MCP;
QENDOW(FD,GATT) = TEMP(FD,GATT)*(QEXPAND(FD,GATT));
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=2;
  SOLVE IBRD USING MCP;
SX(FD,OECD,TR)  = SX(FD,OECD,TR)*(1-.36);
*.TY(FD,OECD)    = (TY(FD,OECD)*.8);
SX(FD,NOECD,TR) = SX(FD,NOECD,TR)*(1-.24);
*.TY(FD,NOECD)    = (TY(FD,NOECD)*.867);
display 'NEW PROTECTION -- ALL CUTS', TM, SX, TY;

****************************************************************
* SOLVE THE COUNTERFACTUAL 
****************************************************************

$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
EXPAND.L(R) = 0;
CONTRACT.L(R) = 0;
SOLVE IBRD USING MCP;

****************************************************************
* REPORT NON-WELFARE RESULTS 
****************************************************************

 windex1(r,'AGR')=C.L(R);

SET WTAB /REAL_W, W_GRAINS, W_PRFOOD, W_R/;
SET GTAB / WAGES, CONGOOD, OTHRMF /;
SET GLOBE / TOTAL /;

PARAMETER      OUTPUT(G,R)         CHANGE IN OUTPUT
          EXPORTS(G,R)        CHANGE IN EXPORTS
          IMPORTS(G,R)        CHANGE IN IMPORTS
          WAGES(R,WTAB)       CHANGE IN REAL WAGES
          WEXPORT(G)          CHANGE IN WORLD TRADE BY SECTOR
          WTRADE(GLOBE)       CHANGE IN WORLD TRADE
          REALGDP(R)          REAL CHANGES IN GDP
          GRAINP(R,GTAB)          CHANGE IN RELATIVE GRAIN PRICES
          STRADE(G,GLOBE)          SECTORAL TRADE
          TTRADE(R,GLOBE)          TOTAL TRADE;

GRAINP(R,'WAGES')  = PA.L('GRAINS',R)/PF.L('LABOUR',R);
GRAINP(R,'CONGOOD')  = PA.L('GRAINS',R)/PC.L(R);
GRAINP(R,'OTHRMF')  = PA.L('GRAINS',R)/PA.L('OTHRMF',R);

OUTPUT(G,R)    =    Y.L(G,R) - 1;
EXPORTS(G,R)   =    (((Y.L(G,R)*Y0(G,R)) - (DOM.L(G,R)*D0(G,R)))/
                            (Y0(G,R)-D0(G,R)))-1;
IMPORTS(G,R)   =    (((A.L(G,R)/PA.L(G,R)) - (DOM.L(G,R)*(D0(G,R)/A0(G,R))))
               * (A0(G,R) / (A0(G,R)-D0(G,R)))) -1 ;
WEXPORT(G)     =    SUM(R,(((Y.L(G,R)*Y0(G,R)) - (DOM.L(G,R)*D0(G,R))))/
                     SUM(TR,(Y0(G,TR)-D0(G,TR))))-1;
WTRADE(GLOBE)  =    SUM(R,SUM(MG,(((Y.L(MG,R)*Y0(MG,R)) -
(DOM.L(MG,R)*D0(MG,R)))))/
                     SUM(TR,SUM(MG,(Y0(MG,TR)-D0(MG,TR)))))-1;
STRADE(G,GLOBE)          =    WEXPORT(G);
TTRADE(R,GLOBE)          =    WTRADE(GLOBE);
WAGES(R,'REAL_W')   =    PF.L('LABOUR',R)/PC.L(R);
WAGES(R,'W_GRAINS') =    PF.L('LABOUR',R)/PA.L('GRAINS',R);
WAGES(R,'W_PRFOOD') =    PF.L('LABOUR',R)/PA.L('PRFOOD',R);
WAGES(R,'W_R')      =    PF.L('LABOUR',R)/PF.L('CAPTAL',R);
REALGDP(R)          =    (SUM(G,(Y.L(G,R)*Y0(G,R))) /
                                SUM(G,Y0(G,R)))-1;
DISPLAY OUTPUT, IMPORTS, EXPORTS, WAGES, REALGDP, WEXPORT, WTRADE;

****************************************************************
* BACK OUT STEADY-STATE EFFECTS 
****************************************************************

SWITCH      = 0;
$INCLUDE IBRD.GEN
  IBRD.OPTFILE=4;
SOLVE IBRD USING MCP;

windex1(r,'DYNAMICS')=C.L(R);

****************************************************************
* REPORT WELFARE RESULTS 
****************************************************************

PARAMETER PERCENT(R,SCENARIO);

PERCENT(R,'TEXT_APP')     =  (WINDEX1(R,'TEXT_APP')/WINDEX0(R)) - 1;
PERCENT(R,'O_IND')   =  (WINDEX1(R,'O_IND')-WINDEX1(R,'TEXT_APP'))/WINDEX0(R);
PERCENT(R,'PRIMARY') =  (WINDEX1(R,'PRIMARY')-WINDEX1(R,'O_IND'))/WINDEX0(R);
PERCENT(R,'AGR')     =  (WINDEX1(R,'AGR')-WINDEX1(R,'PRIMARY'))/WINDEX0(R);
PERCENT(R,'DYNAMICS')= -(WINDEX1(R,'DYNAMICS')-WINDEX1(R,'AGR'))/WINDEX0(R);
PERCENT(R,'TOTAL')   =  (WINDEX1(R,'AGR')/WINDEX0(R)) -1;
BASIS(R) 	     =  BASIS(R) * 10000;
EV(R,SCENARIO)       =  BASIS(R)*PERCENT(R,SCENARIO);

DISPLAY 'WELFARE ESTIMATES', BASIS, WINDEX0, WINDEX1, EV, PERCENT;

FILE PRN /exp3.PRN/;
$BATINCLUDE wrtprn.gms PRN "PERCENT EV FOR STATIC MODEL" PERCENT R SCENARIO
$BATINCLUDE wrtprn.gms PRN "1992 DOLLAR EV" EV R SCENARIO
$BATINCLUDE wrtprn.gms PRN "REAL OUTPUT" OUTPUT G R
$BATINCLUDE wrtprn.gms PRN "EXPORTS" EXPORTS G R
$BATINCLUDE wrtprn.gms PRN "WAGES" WAGES R WTAB
$BATINCLUDE wrtprn.gms PRN "RELATIVE GRAIN PRICES" GRAINP R GTAB
$BATINCLUDE wrtprn.gms PRN "SECTORAL TRADE EFFECTS" STRADE G GLOBE
$BATINCLUDE wrtprn.gms PRN "GLOBAL TRADE EFFECTS" TTRADE R GLOBE
